@@ -1,8 +1,9 @@
 #pragma once
 
 #include "fastfetch.h"
+#include "modules/battery/option.h"
 
-#define FF_BATTERY_TEMP_UNSET (0/0.0)
+#define FF_BATTERY_TEMP_UNSET (-DBL_MAX)
 
 typedef struct FFBatteryResult
 {
@@ -15,6 +16,7 @@ typedef struct FFBatteryResult
     double capacity;
     double temperature;
     uint32_t cycleCount;
+    int32_t timeRemaining; // in seconds, -1 if unknown
 } FFBatteryResult;
 
 const char* ffDetectBattery(FFBatteryOptions* options, FFlist* results);
