@@ -1,12 +1,9 @@
 #include "displayserver.h"
-#include "detection/os/os.h"
 #include "util/windows/unicode.h"
-#include "util/windows/registry.h"
-#include "util/mallocHelper.h"
 #include "util/edidHelper.h"
 
 #include <dwmapi.h>
-#include <WinUser.h>
+#include <winuser.h>
 #include <wchar.h>
 
 typedef struct FFMonitorInfo
@@ -149,12 +146,30 @@ static void detectDisplays(FFDisplayServerResult* ds)
                 default: rotation = 0; break;
             }
 
+            DISPLAYCONFIG_TARGET_PREFERRED_MODE preferredMode = {
+                .header = {
+                    .type = DISPLAYCONFIG_DEVICE_INFO_GET_TARGET_PREFERRED_MODE,
+                    .size = sizeof(preferredMode),
+                    .adapterId = path->targetInfo.adapterId,
+                    .id = path->targetInfo.id,
+                }
+            };
+            double preferredRefreshRate = 0;
+            if (DisplayConfigGetDeviceInfo(&preferredMode.header) == ERROR_SUCCESS)
+            {
+                DISPLAYCONFIG_RATIONAL freq = preferredMode.targetMode.targetVideoSignalInfo.vSyncFreq;
+                preferredRefreshRate = freq.Numerator / (double) freq.Denominator;
+            }
+
             FFDisplayResult* display = ffdsAppendDisplay(ds,
                 width,
                 height,
                 path->targetInfo.refreshRate.Numerator / (double) path->targetInfo.refreshRate.Denominator,
                 (uint32_t) (monitorInfo->info.rcMonitor.right - monitorInfo->info.rcMonitor.left),
                 (uint32_t) (monitorInfo->info.rcMonitor.bottom - monitorInfo->info.rcMonitor.top),
+                preferredMode.width,
+                preferredMode.height,
+                preferredRefreshRate,
                 rotation,
                 &name,
                 path->targetInfo.outputTechnology == DISPLAYCONFIG_OUTPUT_TECHNOLOGY_OTHER ? FF_DISPLAY_TYPE_UNKNOWN :
@@ -171,28 +186,50 @@ static void detectDisplays(FFDisplayServerResult* ds)
 
             if (display)
             {
-                DISPLAYCONFIG_GET_ADVANCED_COLOR_INFO advColorInfo = {
+                DISPLAYCONFIG_GET_ADVANCED_COLOR_INFO_2 advColorInfo2 = {
                     .header = {
-                        .type = DISPLAYCONFIG_DEVICE_INFO_GET_ADVANCED_COLOR_INFO,
-                        .size = sizeof(advColorInfo),
+                        .type = DISPLAYCONFIG_DEVICE_INFO_GET_ADVANCED_COLOR_INFO_2,
+                        .size = sizeof(advColorInfo2),
                         .adapterId = path->targetInfo.adapterId,
                         .id = path->targetInfo.id,
                     }
                 };
-                if (DisplayConfigGetDeviceInfo(&advColorInfo.header) == ERROR_SUCCESS)
+                if (DisplayConfigGetDeviceInfo(&advColorInfo2.header) == ERROR_SUCCESS)
                 {
-                    if (advColorInfo.advancedColorEnabled)
+                    if (advColorInfo2.highDynamicRangeUserEnabled)
                         display->hdrStatus = FF_DISPLAY_HDR_STATUS_ENABLED;
-                    else if (advColorInfo.advancedColorSupported)
+                    else if (advColorInfo2.highDynamicRangeSupported)
                         display->hdrStatus = FF_DISPLAY_HDR_STATUS_SUPPORTED;
                     else
                         display->hdrStatus = FF_DISPLAY_HDR_STATUS_UNSUPPORTED;
-                    display->bitDepth = (uint8_t) advColorInfo.bitsPerColorChannel;
+                    display->bitDepth = (uint8_t) advColorInfo2.bitsPerColorChannel;
                 }
                 else
-                    display->hdrStatus = FF_DISPLAY_HDR_STATUS_UNKNOWN;
+                {
+                    DISPLAYCONFIG_GET_ADVANCED_COLOR_INFO advColorInfo = {
+                        .header = {
+                            .type = DISPLAYCONFIG_DEVICE_INFO_GET_ADVANCED_COLOR_INFO,
+                            .size = sizeof(advColorInfo),
+                            .adapterId = path->targetInfo.adapterId,
+                            .id = path->targetInfo.id,
+                        }
+                    };
+                    if (DisplayConfigGetDeviceInfo(&advColorInfo.header) == ERROR_SUCCESS)
+                    {
+                        if (advColorInfo.advancedColorEnabled)
+                            display->hdrStatus = FF_DISPLAY_HDR_STATUS_ENABLED;
+                        else if (advColorInfo.advancedColorSupported)
+                            display->hdrStatus = FF_DISPLAY_HDR_STATUS_SUPPORTED;
+                        else
+                            display->hdrStatus = FF_DISPLAY_HDR_STATUS_UNSUPPORTED;
+                        display->bitDepth = (uint8_t) advColorInfo.bitsPerColorChannel;
+                    }
+                    else
+                        display->hdrStatus = FF_DISPLAY_HDR_STATUS_UNKNOWN;
+                }
                 if (edidLength > 0)
                     ffEdidGetSerialAndManufactureDate(edidData, &display->serial, &display->manufactureYear, &display->manufactureWeek);
+                display->drrStatus = path->flags & DISPLAYCONFIG_PATH_BOOST_REFRESH_RATE ? FF_DISPLAY_DRR_STATUS_ENABLED : FF_DISPLAY_DRR_STATUS_DISABLED;
             }
         }
     }
@@ -215,22 +252,4 @@ void ffConnectDisplayServerImpl(FFDisplayServerResult* ds)
     }
 
     detectDisplays(ds);
-
-    //https://github.com/hykilpikonna/hyfetch/blob/master/neofetch#L2067
-    const FFOSResult* os = ffDetectOS();
-    if(
-        ffStrbufEqualS(&os->version, "11") ||
-        ffStrbufEqualS(&os->version, "10") ||
-        ffStrbufEqualS(&os->version, "2022") ||
-        ffStrbufEqualS(&os->version, "2019") ||
-        ffStrbufEqualS(&os->version, "2016")
-    ) ffStrbufSetStatic(&ds->dePrettyName, "Fluent");
-    else if(
-        ffStrbufEqualS(&os->version, "8") ||
-        ffStrbufEqualS(&os->version, "8.1") ||
-        ffStrbufEqualS(&os->version, "2012 R2") ||
-        ffStrbufEqualS(&os->version, "2012")
-    ) ffStrbufSetStatic(&ds->dePrettyName, "Metro");
-    else
-        ffStrbufSetStatic(&ds->dePrettyName, "Aero");
 }
