@@ -2,12 +2,14 @@
 #include "common/io/io.h"
 #include "common/printing.h"
 #include "common/processing.h"
+#include "detection/media/media.h"
 #include "detection/os/os.h"
 #include "detection/terminalshell/terminalshell.h"
 #include "util/textModifier.h"
 #include "util/stringUtils.h"
 
 #include <ctype.h>
+#include <stdlib.h>
 #include <string.h>
 
 typedef enum __attribute__((__packed__)) FFLogoSize
@@ -114,7 +116,7 @@ static bool ffLogoPrintCharsRaw(const char* data, size_t length, bool printError
 static uint32_t logoAppendChars(const char* data, bool doColorReplacement, FFstrbuf* result)
 {
     FFOptionsLogo* options = &instance.config.logo;
-    uint32_t currentlineLength = options->width;
+    uint32_t currentlineLength = options->type == FF_LOGO_TYPE_IMAGE_CHAFA ? 0 : options->width; // For chafa, unit of options->width is pixels
     uint32_t logoHeight = 0;
 
     if (result)
@@ -260,7 +262,7 @@ static uint32_t logoAppendChars(const char* data, bool doColorReplacement, FFstr
     if(currentlineLength > instance.state.logoWidth)
         instance.state.logoWidth = currentlineLength;
 
-    return options->height > logoHeight ? options->height : logoHeight;
+    return options->type != FF_LOGO_TYPE_IMAGE_CHAFA && options->height > logoHeight ? options->height : logoHeight;
 }
 
 void ffLogoPrintChars(const char* data, bool doColorReplacement)
@@ -483,6 +485,15 @@ static bool updateLogoPath(void)
     if (ffStrbufEqualS(&options->source, "-")) // stdin
         return true;
 
+    if (ffStrbufIgnCaseEqualS(&options->source, "media-cover"))
+    {
+        const FFMediaResult* media = ffDetectMedia(true);
+        if (media->cover.length == 0)
+            return false;
+        ffStrbufSet(&options->source, &media->cover);
+        return true;
+    }
+
     FF_STRBUF_AUTO_DESTROY fullPath = ffStrbufCreate();
     if (ffPathExpandEnv(options->source.chars, &fullPath) && ffPathExists(fullPath.chars, FF_PATHTYPE_FILE))
     {
@@ -706,6 +717,9 @@ void ffLogoPrintLine(void)
     if(instance.state.logoWidth > 0)
         printf("\033[%uC", instance.state.logoWidth);
 
+    if (instance.state.dynamicInterval > 0)
+        fputs("\033[K", stdout);
+
     ++instance.state.keysHeight;
 }
 
