@@ -4,7 +4,7 @@
 
 #define FF_TERMINALFONT_MODULE_NAME "TerminalFont"
 
-void ffPrintTerminalFont(FFTerminalFontOptions* options);
+bool ffPrintTerminalFont(FFTerminalFontOptions* options);
 void ffInitTerminalFontOptions(FFTerminalFontOptions* options);
 void ffDestroyTerminalFontOptions(FFTerminalFontOptions* options);
 
